/* ============================================================
 *
 * This file is a part of digiKam project
 * http://www.digikam.org
 *
 * Date        : 2003-01-23
 * Description : A widget to display a list of camera folders.
 * 
 * Copyright (C) 2003-2005 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
 * Copyright (C) 2006-2008 by Gilles Caulier <caulier dot gilles at gmail dot com>
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published bythe Free Software Foundation;
 * either version 2, or (at your option)
 * any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * ============================================================ */

#ifndef CAMERAFOLDERVIEW_H
#define CAMERAFOLDERVIEW_H

// TQt includes.

#include <tqstring.h>
#include <tqlistview.h>

// KDE includes.

#include <kiconloader.h>

namespace Digikam
{

class CameraFolderItem;
class CameraFolderViewPriv;

class CameraFolderView : public TQListView
{
    Q_OBJECT
  TQ_OBJECT

public:

    CameraFolderView(TQWidget* tqparent);
    ~CameraFolderView();

    void addVirtualFolder(const TQString& name, const TQPixmap& pixmap=SmallIcon("camera"));
    void addRootFolder(const TQString& folder, int nbItems, const TQPixmap& pixmap=SmallIcon("folder"));

    CameraFolderItem* addFolder(const TQString& folder, const TQString& subFolder, int nbItems, 
                                const TQPixmap& pixmap=SmallIcon("folder"));

    CameraFolderItem* findFolder(const TQString& folderPath);

    CameraFolderItem* virtualFolder();
    CameraFolderItem* rootFolder();

    virtual void clear();

signals:

    void signalFolderChanged(CameraFolderItem*);
    void signalCleared();

private slots:

    void slotCurrentChanged(TQListViewItem*);

private:

    CameraFolderViewPriv* d;

};

} // namespace Digikam

#endif /* CAMERAFOLDERVIEW_H */
